==> agr-center-api-3.2.0-CLOUD-TEST-20240306.031740-9-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrMainChngDetailBo.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainChngDetailBo implements Serializable {
	private static final long serialVersionUID =  7168012966803344244L;

	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保周期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保周期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 是否商城铺货标识
	 */
	private String whetherStorePlanStr;
	/**
	 * 是否有明细标识
	 */
	private String whetherHaveItemStr;

	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 编制人单位
	 */
	private String createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议状态转义
	 */
	private String agrStatusStr;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.2.2-CLOUD-TEST-20250206.034529-7-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrMainChngDetailBo.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainChngDetailBo implements Serializable {
	private static final long serialVersionUID =  7168012966803344244L;

	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保周期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保周期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 是否商城铺货标识
	 */
	private String whetherStorePlanStr;
	/**
	 * 是否有明细标识
	 */
	private String whetherHaveItemStr;

	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 编制人单位
	 */
	private String createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议状态转义
	 */
	private String agrStatusStr;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 是否代理商
	 */
	private Integer agentFlag;
	/**
	 * 是否代理商转义
	 */
	private String agentFlagStr;
	/**
	 * 原厂商名称
	 */
	private String originalManufacturer;
	/**
	 * 是否代管供应商
	 */
	private Integer escrowVendorFlag;
	/**
	 * 是否代管供应商转义
	 */
	private String escrowVendorFlagStr;
	/**
	 * 合同签订依据
	 */
	private String agrMainExtend10;
	/**
	 * 扩展字段5转义：是否共享限额类：0否 1是
	 */
	private String agrMainExtend5Str;
	/**
	 * 扩展字段9：是否自动续约类：0否 1是
	 */
	private String agrMainExtend9Str;
	/**
	 * 协议创建公司ID
	 */
	private Long createCompanyId;
	/**
	 * 协议创建公司名称
	 */
	private String createCompanyName;
	/**
	 * 是否开放二分 1 是 0 否
	 */
	private Integer secondUserFlag;
	/**
	 * 是否开放二分转义
	 */
	private String secondUserFlagStr;
}
